// xorg.conf.h - This file describes all possible xorg.conf files that
// can be created with the configScreen scripts.

// Definition section:
// Stores the configuration used to generate a given xorg.conf file.
// If new macros are added, a new section storing it's value should appear
// below.  Note that it is critical that there be no space between the '#'
// and the first letter, or the C-preprocessor will replace the left-hand
// name with the current value.  Also it's important that a default value be
// provided, in case the machine has not already been configured with
// configScreen

#if WACOM_CONFIG == 2
##_WACOM_CONFIG=2
#elif WACOM_CONFIG == 1
##_WACOM_CONFIG=1
#else
##_WACOM_CONFIG=0
#endif

#if WACOM_TYPE == 2
##_WACOM_TYPE=2
#elif WACOM_TYPE == 1
##_WACOM_TYPE=1
#else
##_WACOM_TYPE=0
#endif

#if WACOM_BUTTON == 1
##_WACOM_BUTTON=1
#else
##_WACOM_BUTTON=0
#endif

#if WACOM_THRESHOLD == 1
##_WACOM_THRESHOLD=1
#elif WACOM_THRESHOLD == 5
##_WACOM_THRESHOLD=5
#elif WACOM_THRESHOLD == 10
##_WACOM_THRESHOLD=10
#else
##_WACOM_THRESHOLD=20
#endif

#if WACOM_PORT == 0
##_WACOM_PORT=0
#elif WACOM_PORT == 1
##_WACOM_PORT=1
#else
##_WACOM_PORT=2
#endif

#if DUAL_SETUP == 1
##_DUAL_SETUP=1
#elif DUAL_SETUP == 2
##_DUAL_SETUP=2
#elif DUAL_SETUP == 3
##_DUAL_SETUP=3
#elif DUAL_SETUP == 4
##_DUAL_SETUP=4
#elif DUAL_SETUP == 5
##_DUAL_SETUP=5
#elif DUAL_SETUP == 6 
##_DUAL_SETUP=6
#else
##_DUAL_SETUP=0
#endif

#if SINGLE_SETUP == 1
##_SINGLE_SETUP=1
#elif SINGLE_SETUP == 2
##_SINGLE_SETUP=2
#elif SINGLE_SETUP == 3
##_SINGLE_SETUP=3
#elif SINGLE_SETUP == 4
##_SINGLE_SETUP=4
#elif SINGLE_SETUP == 5
##_SINGLE_SETUP=5
#elif SINGLE_SETUP == 6
##_SINGLE_SETUP=6
#else 
##_SINGLE_SETUP=0
#endif

#if VERT_ORIENT == 1
##_VERT_ORIENT=1
#elif
##_VERT_ORIENT=2
#else
##_VERT_ORIENT=0
#endif

#if NVIDIA_CIOVERLAY == 1
##_NVIDIA_CIOVERLAY=1
#else
##_NVIDIA_CIOVERLAY=0
#endif

#if WHEEL_MOUSE == 1
##_WHEEL_MOUSE=1
#else
##_WHEEL_MOUSE=0
#endif

#if MX_MOUSE == 1
##_MX_MOUSE=1
#else
##_MX_MOUSE=0
#endif

#if RGS == 1
##_RGS=1
#else
##_RGS=0
#endif

#if STEREO == 1
##_STEREO=1
#else
##_STEREO=0
#endif

Section "ServerLayout"
    Identifier "Layout0"
    Screen     "Screen0"
    InputDevice    "Mouse0" "CorePointer"
    InputDevice    "Keyboard0" "CoreKeyboard"
#if WACOM_CONFIG != 0
    InputDevice	    "pad"    
    InputDevice     "eraser" "AlwaysCore"
    InputDevice     "stylus"  "AlwaysCore"
    InputDevice     "cursor" "AlwaysCore"
#endif
EndSection

Section "Files"
    RgbPath    "/usr/share/X11/rgb"
    FontPath   "unix/:7100"
EndSection

Section "Module"
    Load  "dbe"		# Double-buffering
    Load  "glx"		# OpenGL X protocol interface
    Load  "extmod"	# Misc. required extensions
    Load  "v4l"		# Video4Linux
    Load  "type1"       # Copied from config provided by HP
    Load  "freetype"    # Copied from config provided by HP
#if RGS == 1
    Load  "rge"       # Loads HP Remote Graphics sender
#endif
EndSection

Section "ServerFlags"
    Option "AllowDeactivateGrabs" "true"
    Option "DontZap" "true"
#if DUAL_SETUP != 0
    Option         "Xinerama" "0"
#endif
EndSection

Section "InputDevice"
    Identifier  "Keyboard0"
    Driver      "keyboard"
    Option      "XkbLayout"	"us"
EndSection

Section "InputDevice"
    Identifier  "Mouse0"
    Driver      "mouse"
    Option      "Device" "/dev/input/mice"
    Option      "Emulate3Buttons" "off"
#if MX_MOUSE == 1
    Option      "Protocol" "ExplorerPS/2"
    Option      "ZAxisMapping" "6 7"
    Option      "Buttons" "7"
#elif WHEEL_MOUSE == 1
    Option      "Protocol" "imps/2"
    Option      "ZAxisMapping" "4 5"
#else
    Option      "Protocol" "PS/2"
    Option      "ZAxisMapping" "4 5"
#endif
EndSection

Section "InputDevice"
    Identifier  "stylus"
    Driver      "wacom"
    Option      "Type" "stylus"
    Option      "Tilt" "on"
#if WACOM_PORT == 0
    Option      "USB" "on"
#if WACOM_TYPE == 2
    Option      "Device" "/dev/input/wacom-tablets/cintiq21ux"
#elif WACOM_TYPE == 1
    Option      "Device" "/dev/input/wacom-tablets/intuos3-6x8-tablet"
#else
    Option	"Device" "/dev/input/wacom"
#endif
#elif WACOM_PORT == 1
    Option      "Device" "/dev/ttyS0"
#else
    Option      "Device" "/dev/ttyS1"
#endif
    Option      "Mode" "Absolute"
#if WACOM_THRESHOLD == 1
    Option	"Threshold" "1"
#elif WACOM_THRESHOLD == 5
    Option	"Threshold" "5"
#elif WACOM_THRESHOLD == 10
    Option	"Threshold" "10"
#else
    Option	"Threshold" "20"
#endif
#if WACOM_CONFIG == 2
    Option      "Twinview" "horizontal"
#endif
#if DUAL_SETUP == 6
    Option "TVResolution" "1600x1200,1920x1200"
#endif
#if WACOM_BUTTON == 1
    Option "Button2" "3"
    Option "Button3" "2"
#endif
EndSection

Section "InputDevice"
    Identifier  "eraser"
    Driver      "wacom"
    Option      "Type" "eraser"
#if WACOM_PORT == 0
    Option      "USB" "on"
#if WACOM_TYPE == 2
    Option      "Device" "/dev/input/wacom-tablets/cintiq21ux"
#elif WACOM_TYPE == 1
    Option      "Device" "/dev/input/wacom-tablets/intuos3-6x8-tablet"
#else
    Option	"Device" "/dev/input/wacom"
#endif
#elif WACOM_PORT == 1
    Option      "Device" "/dev/ttyS0"
#else
    Option      "Device" "/dev/ttyS1"
#endif
    Option      "Mode" "Absolute"
#if WACOM_THRESHOLD == 1
    Option	"Threshold" "1"
#elif WACOM_THRESHOLD == 5
    Option	"Threshold" "5"
#elif WACOM_THRESHOLD == 10
    Option	"Threshold" "10"
#else
    Option	"Threshold" "20"
#endif
#if WACOM_CONFIG == 2
    Option      "Twinview" "horizontal"
#endif
#if DUAL_SETUP == 6
    Option "TVResolution" "1600x1200,1920x1200"
#endif
EndSection

Section "InputDevice"
    Identifier  "cursor"
    Driver      "wacom"
    Option      "Type" "cursor"
#if WACOM_PORT == 0
    Option      "USB" "on"
#if WACOM_TYPE == 2
    Option      "Device" "/dev/input/wacom-tablets/cintiq21ux"
#elif WACOM_TYPE == 1
    Option      "Device" "/dev/input/wacom-tablets/intuos3-6x8-tablet"
#else
    Option	"Device" "/dev/input/wacom"
#endif
#elif WACOM_PORT == 1
    Option      "Device" "/dev/ttyS0"
#else
    Option      "Device" "/dev/ttyS1"
#endif
    Option      "Mode" "Relative"
#if WACOM_THRESHOLD == 1
    Option	"Threshold" "1"
#elif WACOM_THRESHOLD == 5
    Option	"Threshold" "5"
#elif WACOM_THRESHOLD == 10
    Option	"Threshold" "10"
#else
    Option	"Threshold" "20"
#endif
#if WACOM_CONFIG == 2
    Option      "Twinview" "horizontal"
#endif
#if DUAL_SETUP == 6
    Option "TVResolution" "1600x1200,1920x1200"
#endif
EndSection

Section "InputDevice"
  Identifier    "pad"
  Driver        "wacom"
  Option        "Type" "pad"
#if WACOM_PORT == 0
    Option      "USB" "on"
#if WACOM_TYPE == 2
    Option      "Device" "/dev/input/wacom-tablets/cintiq21ux"
#elif WACOM_TYPE == 1
    Option      "Device" "/dev/input/wacom-tablets/intuos3-6x8-tablet"
#else
    Option	"Device" "/dev/input/wacom"
#endif
#elif WACOM_PORT == 1
    Option      "Device" "/dev/ttyS0"
#else
    Option      "Device" "/dev/ttyS1"
#endif
EndSection

Section "Monitor"
    Identifier "DreamWorks Monitor"
    VendorName "Unknown"
#if  WACOM_TYPE == 2
    ModelName "WAC Cintiq21UX"
#else
    ModelName  "Unknown"
#endif
    HorizSync 30-200
    VertRefresh 48-200
    Modeline "1280x1024_96"  182.81 1280 1376 1520 1760 1024 1025 1028 1082 -HSync +Vsync
    Modeline "1600x1200_96"  268.78 1600 1728 1904 2208 1200 1201 1204 1268 -HSync +Vsync
//    Modeline "1280x1024_144" 284.64 1280 1384 1528 1776 1024 1025 1028 1113 -HSync +Vsync
//    Modeline "1600x1200_144" 420.62 1600 1744 1920 2240 1200 1201 1204 1304 -HSync +Vsync
EndSection

Section "Device"
    Identifier "Videocard0"
    VendorName "NVIDIA Corporation"
    Driver "nvidia"
    Option "NoLogo" "yes"
    Option "ConstantFrameRateHint" "true"
    Option "EmulatedOverlaysTimerMs" "10"
#if STEREO == 0
#if RGS == 1
    Option "NoFlip" "on"
#endif
#if NVIDIA_CIOVERLAY == 1
    Option "CIOverlay"
#endif
#else
    Option "Stereo" "3"
#endif
#if VERT_ORIENT == 1
    Option "Rotate" "left"
#elif VERT_ORIENT == 2
    Option "Rotate" "right"
#endif
EndSection

Section "Screen"
    Identifier "Screen0"
    Device      "Videocard0"
    Monitor     "DreamWorks Monitor"
    DefaultDepth 24

#if DUAL_SETUP != 0     //dual screen options start
    Option "TwinView" "yes"
#if VERT_ORIENT == 1
    Option "TwinViewOrientation" "DFP-0 Below DFP-1"
#elif VERT_ORIENT == 2
    Option "TwinViewOrientation" "DFP-0 Above DFP-1"
#else
#if (DUAL_SETUP == 4 || DUAL_SETUP == 5)
    Option "TwinViewOrientation" "CRT-0 LeftOf CRT-1"
#else
    Option "TwinViewOrientation" "DFP-0 LeftOf DFP-1"
#endif
#endif
#if DUAL_SETUP == 1
    Option "TwinViewXineramaInfoOrder" "DFP-0"
    Option "metamodes" "DFP-0: 1920x1200_60, DFP-1: 1920x1200_60"
#elif DUAL_SETUP == 2
    Option "TwinViewXineramaInfoOrder" "DFP-0"
    Option "metamodes" "DFP-0: 1600x1200_60, DFP-1: 1600x1200_60"
#elif DUAL_SETUP == 3
    Option "TwinViewXineramaInfoOrder" "DFP-0"
    Option "metamodes" "DFP-0: 1280x1024_60, DFP-1: 1280x1024_60"
#elif DUAL_SETUP == 4
    Option "TwinViewXineramaInfoOrder" "CRT-0"
#if STEREO == 0
    Option "metamodes" "CRT-0: 1600x1200_85, CRT-1: 1600x1200_85"
#else
    Option "metamodes" "CRT-0: 1600x1200_96, CRT-1: 1600x1200_96"
#endif
#elif DUAL_SETUP == 5
    Option "TwinViewXineramaInfoOrder" "CRT-0"
#if STEREO == 0
    Option "metamodes" "CRT-0: 1280x1024_85, CRT-1: 1280x1024_85"
#else
    Option "metamodes" "CRT-0: 1280x1024_96, CRT-1: 1280x1024_96"
#endif
#elif DUAL_SETUP == 6
    Option "TwinViewXineramaInfoOrder" "DFP-0"
    Option "metamodes" "DFP-0: 1600x1200_60, DFP-1: 1920x1200_60; DFP-0: 1600x1200, DFP-1: 1920x1600"
#endif  	// DUAL_SETUP ENDS
#else
#if SINGLE_SETUP == 1
    Option "TwinViewXineramaInfoOrder" "DFP-0"
    Option "metamodes" "DFP-0: 1920x1200_60"
#elif SINGLE_SETUP == 2
    Option "TwinViewXineramaInfoOrder" "DFP-0"
    Option "metamodes" "DFP-0: 1600x1200_60"
#elif SINGLE_SETUP == 3
    Option "TwinViewXineramaInfoOrder" "DFP-0"
    Option "metamodes" "DFP-0: 1280x1024_60"
#elif SINGLE_SETUP == 4
    Option "TwinViewXineramaInfoOrder" "CRT-0"
#if STEREO == 0
    Option "metamodes" "CRT-0: 1600x1200_85"
#else
    Option "metamodes" "CRT-0: 1600x1200_96"
#endif
#elif SINGLE_SETUP == 5
    Option "TwinViewXineramaInfoOrder" "CRT-0"
#if STEREO == 0
    Option "metamodes" "CRT-0: 1280x1024_85"
#else
    Option "metamodes" "CRT-0: 1280x1024_96"
#endif
#elif SINGLE_SETUP == 6
    Option "TwinView" "yes"
    Option "TwinViewOrientation" "DFP-0 LeftOf DFP-1"
    Option "TwinViewXineramaInfoOrder" "DFP-0"
    Option "metamodes" "DFP-0: 1600x1200_60, DFP-1: 1600x1200_60"
#endif 		// SINGLE_SETUP ENDS

#if STEREO == 0
    Option "UseEdidFreqs" "yes"
#endif
#endif                       //End of dual screen options

    Subsection "Display"
        Depth       24
    EndSubsection
EndSection

// Interface description section:
    // There are currently three supported syntaxes:
    //
    // <Category-name>#|<Value-name>#|<Value-setting>
    //       This adds a Value with the given name and setting as a radio
    //       button under the given Category.  It also creates the Category  
    //       if necessary
    //
    // <Category-name>#|<Value-name>#|<Value-setting>#?<Condition-script>
    //       Does the same thing as the first line, except that it first
    //       runs the shell script <Condition-script>.  If the script
    //       returns no output then the Value is not created in the Category.
    //
    // <Category-name1>#|<Category-name2>#|<Value-setting>
    //       Sets <Category-name2>, <Value-setting> a control for
    //       <Category-name1>.  This means that only when <Category-name2>
    //       is set to <Value-setting> are the controls in <Category-name1>
    //       active.

// WACOM_CONFIG#Decho 0
// Wacom Config#|Preserve Aspect Ratio#|WACOM_CONFIG=2
// Wacom Config#|Full Screen#|WACOM_CONFIG=1
// Wacom Config#|Off#|WACOM_CONFIG=0
//
// WACOM_TYPE#Decho 0
// Wacom Type#|Intuous 1 or 2 tablet#|WACOM_TYPE=0
// Wacom Type#|Intuous 3 tablet#|WACOM_TYPE=1
// Wacom Type#|Cintiq Monitor (no Stereo)#|WACOM_TYPE=2
//
// WACOM_THRESHOLD#Decho 20
// Wacom Threshold#|1#|WACOM_THRESHOLD=1
// Wacom Threshold#|5#|WACOM_THRESHOLD=5
// Wacom Threshold#|10#|WACOM_THRESHOLD=10
// Wacom Threshold#|20#|WACOM_THRESHOLD=20
//
// WACOM_BUTTON#Decho 0
// Wacom Buttons#|Standard#|WACOM_BUTTON=0
// Wacom Buttons#|Swap Buttons#|WACOM_BUTTON=1
//
// WACOM_PORT#Decho `((/sbin/lsusb | grep -i wacom >& /dev/null) && echo 0) || (/usr/sbin/dmidecode | grep COM | sed -e 's/.*COM[ ]*//' | tr 'AB' '12' | tail -1)`
// Wacom Port#|USB#|WACOM_PORT=0
// Wacom Port#|ttyS0#|WACOM_PORT=1
// Wacom Port#|ttyS1#|WACOM_PORT=2
//
// RGS#D(test -d /opt/hpremote) && echo 1
// RemoteGraphics#|Off#|RGS=0#?(test -d /opt/hpremote) && echo 1
// RemoteGraphics#|Remote Graphics On#|RGS=1#?(test -d /opt/hpremote) && echo 1
//
// DUAL_SETUP#Decho 0
// Multi Monitor Setups#|Use Single Setup#|DUAL_SETUP=0
// Multi Monitor Setups#|2 LCDs at 1920x1200 (24")#|DUAL_SETUP=1
// Multi Monitor Setups#|2 LCDs at 1600x1200#|DUAL_SETUP=2
// Multi Monitor Setups#|2 LCDs at 1280x1024#|DUAL_SETUP=3
// Multi Monitor Setups#|2 CRTs at 1600x1200#|DUAL_SETUP=4
// Multi Monitor Setups#|2 CRTs at 1280x1024#|DUAL_SETUP=5
// Multi Monitor Setups#|2 LCDs with Cintiq#|DUAL_SETUP=6
//
// SINGLE_SETUP#Decho 3
// Single Monitor Setups#|Use Multi Setup#|SINGLE_SETUP=0
// Single Monitor Setups#|1 LCD at 1920x1200 (24")#|SINGLE_SETUP=1
// Single Monitor Setups#|1 LCD at 1600x1200#|SINGLE_SETUP=2
// Single Monitor Setups#|1 LCD at 1280x1024#|SINGLE_SETUP=3
// Single Monitor Setups#|1 CRT at 1600x1200#|SINGLE_SETUP=4
// Single Monitor Setups#|1 CRT at 1280x1024#|SINGLE_SETUP=5
// Single Monitor Setups#|1 LCD with Cintiq#|SINGLE_SETUP=6
//
// NVIDIA_CIOVERLAY#Decho 1
// Overlays#|Off#|NVIDIA_CIOVERLAY=0
// Overlays#|On#|NVIDIA_CIOVERLAY=1
// 
// STEREO#Decho 0
// Stereo 3-D#|Off#|STEREO=0
// Stereo 3-D#|On (CRTs only)#|STEREO=1
//
// WHEEL_MOUSE#Decho 0
// Wheel Mouse#|Off#|WHEEL_MOUSE=0
// Wheel Mouse#|On#|WHEEL_MOUSE=1
//
// MX_MOUSE#Decho 0
// MX310 Mouse#|Off#|MX_MOUSE=0
// MX310 Mouse#|On#|MX_MOUSE=1
//
// VERT_ORIENT#Decho 0
// Vertical Orientation#|Off#|VERT_ORIENT=0
// Vertical Orientation#|Rotate Left (24" LCD only)#|VERT_ORIENT=1
// Vertical Orientation#|Rotate Right (24" LCD only)#|VERT_ORIENT=2
